@@ -229,6 +229,7 @@ module Msf
 
         ldap_entry_cache << domain_object
         domain_sid = Rex::Proto::MsDtyp::MsDtypSid.read(domain_object[:objectSid].first)
+        domain_behavior_version = domain_object['msds-behavior-version'].first
 
         root_dse = ldap.search(
           base: '',
@@ -247,12 +248,33 @@ module Msf
         ldap_entry_cache << xref
 
         {
+          domain_behavior_version: domain_behavior_version.to_i,
           netbios_name: xref[:nETBIOSName].first.to_s,
           dns_name: xref[:dNSRoot].first.to_s,
           sid: domain_sid
         }
       end
 
+      # Query the LDAP server to retrieve all Certificate Authority (Enterprise CA) servers in the domain.
+      # @param [Net::LDAP::Connection] ldap The LDAP connection to use for querying.
+      # @return [Array<Hash>] An array of hashes, where each hash contains the `:name` and `:dNSHostName` of a CA server.
+      # @rtype [Array<Hash>]
+      def adds_get_ca_servers(ldap)
+        base_dn = "CN=Enrollment Services,CN=Public Key Services,CN=Services,CN=Configuration,#{@base_dn}"
+        filter = '(objectClass=pKIEnrollmentService)'
+        attributes = ['cn', 'dNSHostName']
+        ca_servers = []
+
+        ldap.search(base: base_dn, filter: filter, attributes: attributes) do |entry|
+          ca_servers << {
+            name: entry[:cn]&.first,
+            dNSHostName: entry[:dNSHostName]&.first
+          }
+        end
+
+        ca_servers
+      end
+
       # Determine if a security descriptor will grant the permissions identified by *matcher* to the
       # *test_sid*.
       #
